@@ -23,26 +23,25 @@
 #ifndef MDWSLIDER_H
 #define MDWSLIDER_H
 
-#include "volumeslider.h"
-#include <QCheckBox>
-#include <QList>
-#include <QWidget>
 #include <qlist.h>
-#include <qpixmap.h>
+
+#include <kiconloader.h>
+
+#include "gui/volumeslider.h"
+#include "gui/mixdevicewidget.h"
+#include "core/volume.h"
+
 
 class QBoxLayout;
+class QGridLayout;
 class QToolButton;
 class QLabel;
 class QMenu;
 
-#include <kiconloader.h>
-
 class MixDevice;
 class VerticalText;
 class ViewBase;
-
-#include "gui/mixdevicewidget.h"
-#include "core/volume.h"
+class ToggleToolButton;
 
 
 class MDWSlider : public MixDeviceWidget
@@ -50,10 +49,7 @@ class MDWSlider : public MixDeviceWidget
     Q_OBJECT
 
 public:
-    MDWSlider( shared_ptr<MixDevice> md,
-	       bool includePlayback, bool includeCapture,
-	       bool includeMixerName, bool small, Qt::Orientation,
-	       QWidget* parent, ViewBase* view, ProfControl *pctl);
+    MDWSlider(shared_ptr<MixDevice> md, MixDeviceWidget::MDWFlags flags, ViewBase *view, ProfControl *pctl = nullptr);
     virtual ~MDWSlider();
 
     enum LabelType { LT_ALL, LT_FIRST_CAPTURE, LT_NONE };
@@ -67,29 +63,25 @@ public:
     void setLabeled( bool value ) Q_DECL_OVERRIDE;
     void setTicks( bool ticks ) Q_DECL_OVERRIDE;
     void setIcons( bool value ) Q_DECL_OVERRIDE;
-//    void setIcon( QString filename, QLabel** label );
-    void setIcon( QString filename, QWidget* label );
+
     QToolButton* addMediaButton(QString iconName, QLayout* layout, QWidget *parent);
     void updateMediaButton();
     void setColors( QColor high, QColor low, QColor back ) Q_DECL_OVERRIDE;
     void setMutedColors( QColor high, QColor low, QColor back ) Q_DECL_OVERRIDE;
     
-    bool eventFilter( QObject* obj, QEvent* e ) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *obj, QEvent *ev) Q_DECL_OVERRIDE;
+
     QString iconName();
     // Layout
     QSizePolicy sizePolicy() const;
 	QSize sizeHint() const Q_DECL_OVERRIDE;
-	int labelExtentHint() const;
-	void setLabelExtent(int extent);
+    int labelExtentHint() const Q_DECL_OVERRIDE;
+    void setLabelExtent(int extent) Q_DECL_OVERRIDE;
 	bool hasMuteButton() const;
-	void setMuteButtonSpace(bool);
-	void setCaptureLEDSpace(bool);
 	bool hasCaptureLED() const;
 
-	static VolumeSliderExtraData DummVolumeSliderExtraData;
 	static bool debugMe;
-    
-    
+
 public slots:
     void toggleRecsrc();
     void toggleMuted();
@@ -103,9 +95,8 @@ public slots:
     VolumeSliderExtraData& extraData(QAbstractSlider *slider);
     void addMediaControls(QBoxLayout* arg1);
 
-
 private slots:
-    void setRecsrc( bool value );
+    void setRecsrc(bool value);
     void setMuted(bool value);
     void volumeChange( int );
     void sliderPressed();
@@ -122,11 +113,9 @@ private slots:
     void mediaPrev(bool);
 
 private:
-    QPixmap loadIcon( QString filename, KIconLoader::Group group );
-    void createWidgets( bool showMuteLED, bool showCaptureLED, bool includeMixer );
+    void createWidgets();
     void addSliders( QBoxLayout *volLayout, char type, Volume& vol,
                      QList<QAbstractSlider *>& ref_sliders, QString tooltipText );
-    //void addDefaultLabel(QBoxLayout *layout, Qt::Orientation orientation);
 
     // Methods that are called two times from a wrapper. Once for playabck, once for capture
     void setStereoLinkedInternal( QList< QAbstractSlider* >& ref_sliders, bool showSubcontrolLabels);
@@ -137,35 +126,26 @@ private:
     void updateAccesability();
 #endif
 
-    QWidget* createLabel(QWidget* parent, QString& label, QBoxLayout *layout, bool);
 	QString calculatePlaybackIcon(MediaController::PlayState playState);
-	void guiAddSlidersAndMediacontrols(bool playSliders, bool capSliders, bool mediaControls, QBoxLayout* layout, const QString& tooltipText, const QString& captureTooltipText);
-	void guiAddCaptureCheckbox(bool wantsCaptureLED, const Qt::Alignment& alignmentForCapture,
-		QBoxLayout* layoutForCapture, const QString& captureTooltipText);
-	void guiAddMuteButton(bool wantsMuteButton, Qt::Alignment alignment, QBoxLayout* layoutForMuteButton, const QString& muteTooltipText);
-	void guiAddControlIcon(Qt::Alignment alignment, QBoxLayout* layout, const QString& tooltipText);
+	QWidget *guiAddButtonSpacer();
+	void guiAddCaptureButton(const QString &captureTooltipText);
+	void guiAddMuteButton(const QString &muteTooltipText);
+	void guiAddControlIcon(const QString &tooltipText);
+	void guiAddControlLabel(Qt::Alignment alignment, const QString &channelName);
 	void addGlobalShortcut(QAction* action, const QString& label, bool dynamicControl);
+    QSize controlButtonSize();
 
     bool m_linked;
 
-	QWidget *muteButtonSpacer;
-	QWidget *captureSpacer;
-	QWidget *labelSpacer;
+    QGridLayout *m_controlGrid;
 
-    // GUI: Top portion ( Icon + Mute)
-	QLabel      *m_iconLabelSimple;
-	QToolButton* m_qcb;
-	QLabel* m_muteText;
-        
-	QLabel *m_label; // is either QLabel or VerticalText
-	QToolButton *mediaButton;
+	QLabel      *m_controlIcon;
+	QLabel *m_controlLabel; // is either QLabel or VerticalText
 
-	QCheckBox* m_captureCheckbox;
-    QLabel* m_captureText;
-
-	int labelSpacing;
-	bool muteButtonSpacing;
-	bool captureLEDSpacing;
+	ToggleToolButton *m_muteButton;
+	ToggleToolButton *m_captureButton;
+	QToolButton *m_mediaPlayButton;
+	QSize m_controlButtonSize;
 
     KActionCollection*   _mdwMoveActions;
     QMenu *m_moveMenu;
